@@ -1,5 +1,5 @@
 import socket
-from server_constants import *
+from src.server_constants import *
 
 class Connection():
     '''A socket connection class to be used as a server'''
