@@ -1,8 +1,8 @@
 #Online Multiplayer Game Server
-from ast import main
-from server_connection import *
-from server_player import *
-from server_game import *
+
+from src.server_connection import *
+from src.server_player import *
+from src.server_game import *
 import sys
 
 def start_server(IP_ADDR=''):
